summaryrefslogtreecommitdiff
path: root/basic/source/sbx/sbxcurr.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'basic/source/sbx/sbxcurr.cxx')
-rw-r--r--basic/source/sbx/sbxcurr.cxx6
1 files changed, 3 insertions, 3 deletions
diff --git a/basic/source/sbx/sbxcurr.cxx b/basic/source/sbx/sbxcurr.cxx
index 328bbcf72a9c..422c0dde799c 100644
--- a/basic/source/sbx/sbxcurr.cxx
+++ b/basic/source/sbx/sbxcurr.cxx
@@ -54,8 +54,8 @@ static OUString ImpCurrencyToString( const sal_Int64 &rVal )
#ifdef MAYBEFUTURE
if ( initialLen > 5 )
{
- sal_Int32 nThouSeperators = ( initialLen - 5 ) / 3;
- nCapacity += nThouSeperators;
+ sal_Int32 nThouSeparators = ( initialLen - 5 ) / 3;
+ nCapacity += nThouSeparators;
}
#endif
}
@@ -158,7 +158,7 @@ static sal_Int64 ImpStringToCurrency( const OUString &rStr )
OUString sTmp( rStr.trim() );
const sal_Unicode* p = sTmp.getStr();
// normalise string number by removeing thousands & decimal point seperators
OUStringBuffer sNormalisedNumString( sTmp.getLength() + nFractDigit );
if ( *p == '-' || *p == '+' )
@@ -158,7 +158,7 @@ static sal_Int64 ImpStringToCurrency( const OUString &rStr )
OUString sTmp( rStr.trim() );
const sal_Unicode* p = sTmp.getStr();
- // normalise string number by removeing thousands & decimal point seperators
+ // normalise string number by removeing thousands & decimal point separators
OUStringBuffer sNormalisedNumString( sTmp.getLength() + nFractDigit );
if ( *p == '-' || *p == '+' )